@@ -1,4 +1,4 @@
-fitlnorm <- function(x, trunc, start.value, trueLL = TRUE, dec.places = 0, ...){
+fitlnorm <- function(x, trunc, start.value, ...){
   dots <- list(...)
   if (!missing(trunc)){
     if (min(x)<=trunc) stop("truncation point should be lower than the lowest data value")
@@ -15,10 +15,6 @@ fitlnorm <- function(x, trunc, start.value, trueLL = TRUE, dec.places = 0, ...){
   } else {
     LL <- function(meanlog, sdlog) -sum(dtrunc("lnorm", x, coef = list(meanlog = meanlog, sdlog = sdlog), trunc = trunc, log = TRUE))
   }  
-  result <- mle2(LL, start = list(meanlog = meanlog, sdlog = sdlog), data = list(x = x), ...)
-  if(trueLL){
-    warning("trueLL used, \n check if the precision in your data matches the dec.places argument \n")
-    result@min <- -trueLL(x = x, dens = "lnorm", coef = result@coef, trunc, dec.places = dec.places, log = TRUE, ...)
-  }
+  result <- do.call("mle2", c(list(LL, start = list(meanlog = meanlog, sdlog = sdlog), data = list(x = x)), ...))
   new("fitsad", result, sad="lnorm", distr = "C", trunc = ifelse(missing(trunc), NaN, trunc)) 
 }
