@@ -11,13 +11,13 @@ fitmzsm <- function(x, trunc, start.value, upper = length(x), ...){
     thetahat <- start.value
   }
   if (missing(trunc)){
-    LL <- function(theta) -sum(dmzsm(x, J = sum(x), theta = theta, log = TRUE))
+    LL <- function(J, theta) -sum(dmzsm(x, J=J, theta = theta, log = TRUE))
   }
   else
     {
-      LL <- function(theta) -sum(dtrunc("mzsm", x=x, coef = list(J = sum(x), theta = theta), trunc = trunc, log = TRUE))
+      LL <- function(J, theta) -sum(dtrunc("mzsm", x=x, coef = list(J = J, theta = theta), trunc = trunc, log = TRUE))
     }  
-  result <- mle2(LL, start = list(theta = thetahat), data = list(x = x), method ="Brent", lower=0.001, upper=upper, ...)
+  result <- do.call("mle2", c(list(LL, start = list(theta = thetahat), fixed=list(J=sum(x)), data = list(x = x), method ="Brent", lower=0.001, upper=upper), ...))
   if(abs(as.numeric(result@coef) - upper) < 0.0000001) warning("mle equal to upper bound provided. \n Try value for the 'upper' arguent")
   new("fitsad", result, sad="mzsm", distr = "D", trunc = ifelse(missing(trunc), NaN, trunc)) 
 }
